<!DOCTYPE html><html><head><title></title></head><body>
<script type="text/javascript">
	opener.AnyLinkAddOrChangeWidget.callback(window, {{ link_id }}, '{{ link_name }}');
	window.close();
</script></body></html>
