<!DOCTYPE html><html><head><title></title></head><body>
<script type="text/javascript">
	opener.tinymce.plugins.AnyLink.popupCallback('{{ editor_id }}', '{{ link_id }}');
	window.close();
</script></body></html>
